@@ -207,18 +207,17 @@ saAmfDispatch (
 			error = CS_OK;
 			goto error_put;
 		}
-		if (error != CS_OK) {
-			goto error_put;
-		}
-
-
-		if (dispatch_data == NULL) {
+		if (error == CS_ERR_TRY_AGAIN) {
+			error = CS_OK;
 			if (dispatchFlags == CPG_DISPATCH_ALL) {
 				break; /* exit do while cont is 1 loop */
 			} else {
 				continue; /* next poll */
 			}
 		}
+		if (error != CS_OK) {
+			goto error_put;
+		}
 
 		/*
 		 * Make copy of callbacks, message data, unlock instance, and call callback
