@@ -7,7 +7,7 @@
  * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -36,11 +36,11 @@
 #ifndef AIS_UTIL_H_DEFINED
 #define AIS_UTIL_H_DEFINED
 
+#include <saAis.h>
 #include <pthread.h>
 #include <sys/poll.h>
 #include <sys/socket.h>
 
-#include <corosync/ipc_gen.h>
 
 struct saVersionDatabase {
 	int versionCount;
@@ -54,5 +54,24 @@ saVersionVerify (
 
 SaTimeT clustTimeNow(void);
 
-#endif /* AIS_UTIL_H_DEFINED */
+#define IPC_REQUEST_SIZE	8192*128
+#define IPC_RESPONSE_SIZE	8192*128
+#define IPC_DISPATCH_SIZE	8192*128
 
+static inline SaAisErrorT hdb_error_to_sa (int res)		\
+{								\
+	if (res == 0) {						\
+		return (SA_AIS_OK);				\
+	} else {						\
+		if (errno == EBADF) {				\
+			return (SA_AIS_ERR_BAD_HANDLE);		\
+		} else						\
+		if (errno == ENOMEM) {				\
+			return (SA_AIS_ERR_NO_MEMORY);		\
+		}						\
+		return (SA_AIS_ERR_LIBRARY);			\
+	}							\
+}
+
+
+#endif /* AIS_UTIL_H_DEFINED */
