@@ -1,5 +1,5 @@
 /** @file amfsi.c
- * 
+ *
  * Copyright (c) 2006 Ericsson AB.
  * Author: Hans Feldt, Anders Eriksson, Lars Holm
  * - Refactoring of code into several AMF files
@@ -11,7 +11,7 @@
  *
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -35,9 +35,9 @@
  * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGE.
- * 
+ *
  * AMF Workload related classes Implementation
- * 
+ *
  * This file contains functions for handling :
  *	- AMF service instances(SI)
  *	- AMF SI Dependency
@@ -48,10 +48,10 @@
  *	- AMF CSI Type
  *	- AMF CSI Attribute
  * The file can be viewed as the implementation of the classes listed above
- * as described in SAI-Overview-B.02.01. The SA Forum specification 
+ * as described in SAI-Overview-B.02.01. The SA Forum specification
  * SAI-AIS-AMF-B.02.01 has been used as specification of the behaviour
  * and is referred to as 'the spec' below.
- * 
+ *
  * The functions in this file are responsible for:
  * - calculating and storing an SI_dependency_level integer per SI
  * - calculating and storing a csi_dependency_level integer per CSI
@@ -63,9 +63,9 @@
  * The si_dependency_level is an attribute calculated at init (in the future
  * also at reconfiguration) which indicates dependencies between SIs as
  * an integer. The si_dependency level indicates to which extent an SI depends
- * on other SIs such that an SI that depends on no other SI is on 
+ * on other SIs such that an SI that depends on no other SI is on
  * si_dependecy_level == 1, an SI that depends only on an SI on
- * si_dependency_level == 1 is on si_dependency-level == 2. 
+ * si_dependency_level == 1 is on si_dependency-level == 2.
  * An SI that depends on several SIs gets a si_dependency_level that is one
  * unit higher than the SI with the highest si_dependency_level it depends on.
  *
@@ -80,7 +80,7 @@
  * components to assume a new HA state for a CSI-assignment and to guarantee
  * the dependency rules, the active response from the component has to be
  * awaited before next HA state can be set.
- * 
+ *
  * This file implements an SI state machine that fully implements these rules.
  * This state machine is called SI Dependency Control State Machine (dcsm)
  * and has the following states:
@@ -102,30 +102,37 @@
  *							  state)
  *	- SETTING (a request to change the HA state when neither the existing
  *			   nor the requested state is ACTIVE)
- * 
+ *
  * This file also implements:
  *	- SI:             Assignment state (for report purposes)
  *	- SI Assignment:  HA state
  *	- CSI Assignment: HA state
- * 
+ *
  */
 
+#include <config.h>
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include "amf.h"
 #include <netinet/in.h>
-#include <corosync/ipc_gen.h>
 #include <corosync/engine/coroapi.h>
 #include <corosync/engine/logsys.h>
 
-LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+LOGSYS_DECLARE_SUBSYS ("AMF");
+
+void amfsi_init (void)
+{
+#ifdef OPENAIS_SOLARIS
+	logsys_subsys_init();
+#endif
+}
 
 /**
  * Check that all CSI assignments belonging to an SI assignment
  * has been removed.
  * @param si_assignment
- * 
+ *
  * @return int
  */
 static int all_csi_assignments_removed (amf_si_assignment_t *si_assignment)
@@ -138,7 +145,7 @@ static int all_csi_assignments_removed (amf_si_assignment_t *si_assignment)
 		for (csi_assignment = csi->assigned_csis; csi_assignment != NULL;
 			csi_assignment = csi_assignment->next) {
 
-			/* 
+			/*
 			 * If the CSI assignment and the SI assignment belongs to the
 			 * same SU, we have a match and can request the component to
 			 * remove the CSI.
@@ -162,7 +169,7 @@ static int all_csi_assignments_removed (amf_si_assignment_t *si_assignment)
  * state.
  * @param su
  * @param hastate
- * 
+ *
  * @return int
  */
 static int any_csi_has_hastate_in_su (struct amf_su *su, SaAmfHAStateT hastate)
@@ -194,7 +201,7 @@ static int any_csi_has_hastate_in_su (struct amf_su *su, SaAmfHAStateT hastate)
  * an SI assignemnt has the requested state.
  * @param su
  * @param hastate
- * 
+ *
  * @return int
  */
 static int all_csi_has_hastate_for_si (
@@ -263,7 +270,7 @@ static void set_si_ha_state (struct amf_csi_assignment *csi_assignment)
 
 	/* log changes to HA state */
 	if (old_ha_state != csi_assignment->si_assignment->saAmfSISUHAState) {
-		log_printf (LOG_NOTICE, "SU HA state changed to '%s' for:\n"
+		log_printf (LOGSYS_LEVEL_NOTICE, "SU HA state changed to '%s' for:\n"
 			"\t\tSI '%s', SU '%s'",
 			amf_ha_state (csi_assignment->si_assignment->saAmfSISUHAState),
 			csi_assignment->si_assignment->si->name.value,
@@ -273,7 +280,7 @@ static void set_si_ha_state (struct amf_csi_assignment *csi_assignment)
 	/* log changes to assignment state */
 	if (old_assigment_state !=
 		amf_si_get_saAmfSIAssignmentState (csi_assignment->csi->si)) {
-		log_printf (LOG_NOTICE, "SI Assignment state changed to '%s' for:\n"
+		log_printf (LOGSYS_LEVEL_NOTICE, "SI Assignment state changed to '%s' for:\n"
 			"\t\tSI '%s', SU '%s'",
 			amf_assignment_state (
 			amf_si_get_saAmfSIAssignmentState (csi_assignment->csi->si)),
@@ -303,7 +310,7 @@ void amf_si_comp_set_ha_state_done (
 
 	assert (csi_assignment->si_assignment->assumed_callback_fn != NULL);
 
-	/*                                                              
+	/*
 	 * Report to caller when the requested SI assignment state is
 	 * confirmed.
 	 */
@@ -333,7 +340,7 @@ void amf_si_activate (
 			csi_assignment->si_assignment->requested_ha_state =
 				SA_AMF_HA_ACTIVE;
 
-			/*                                                              
+			/*
 			 * TODO: only active assignments should be set when dependency
 			 * levels are used.
 			 */
@@ -376,7 +383,7 @@ void amf_si_ha_state_assume (
 		for (csi_assignment = csi->assigned_csis; csi_assignment != NULL;
 			csi_assignment = csi_assignment->next) {
 
-			/*                                                              
+			/*
 			 * If the CSI assignment and the SI assignment belongs to the
 			 * same SU, we have a match and can request the component to
 			 * change HA state.
@@ -399,7 +406,7 @@ void amf_si_ha_state_assume (
 		}
 	}
 
-	/*                                                              
+	/*
 	 * If the SU has only one component which is the faulty one, we
 	 * will not get an asynchronous response from the component.
 	 * This response (amf_si_comp_set_ha_state_done) is used to do
@@ -417,11 +424,11 @@ void amf_si_ha_state_assume (
 /**
  * Get number of active assignments for the specified SI
  * @param si
- * 
+ *
  * @return int
  */
 int amf_si_get_saAmfSINumCurrActiveAssignments (struct amf_si *si)
-	
+
 {
 	int cnt = 0;
 	struct amf_si_assignment *si_assignment;
@@ -446,7 +453,7 @@ int amf_si_su_get_saAmfSINumCurrActiveAssignments (struct amf_si *si,
 	for (si_assignment = si->assigned_sis; si_assignment != NULL;
 		si_assignment = si_assignment->next) {
 
-		if (si_assignment->su == su && 
+		if (si_assignment->su == su &&
 			si_assignment->saAmfSISUHAState == SA_AMF_HA_ACTIVE) {
 			cnt++;
 		}
@@ -507,9 +514,10 @@ SaAmfAssignmentStateT amf_si_get_saAmfSIAssignmentState (struct amf_si *si)
 void amf_csi_delete_assignments (struct amf_csi *csi, struct amf_su *su)
 {
 	struct amf_csi_assignment *csi_assignment;
-	ENTER ();
 	struct amf_csi_assignment **prev = &csi->assigned_csis;
 
+	ENTER ();
+
 	for (csi_assignment = csi->assigned_csis; csi_assignment != NULL;
 		csi_assignment = csi_assignment->next) {
 		if (csi_assignment->comp->su == su) {
@@ -529,10 +537,10 @@ void amf_csi_delete_assignments (struct amf_csi *csi, struct amf_su *su)
  * valid SI object, out-of-memory problems are handled here.
  * Default values are initialized.
  * @param app
- * 
+ *
  * @return struct amf_si*
  */
-struct amf_si *amf_si_new (struct amf_application *app, char *name)
+struct amf_si *amf_si_new (struct amf_application *app, const char *name)
 {
 	struct amf_si *tail = app->si_head;
 	struct amf_si *si = amf_calloc (1, sizeof (struct amf_si));
@@ -609,10 +617,12 @@ void *amf_si_serialize (struct amf_si *si, int *len)
 	return buf;
 }
 
-struct amf_si *amf_si_deserialize (struct amf_application *app, char *buf) 
+struct amf_si *amf_si_deserialize (struct amf_application *app, char *buf)
 {
 	char *tmp = buf;
-	struct amf_si *si = amf_si_new (app, "");
+	struct amf_si *si;
+
+	si = amf_si_new (app, "");
 
 	tmp = amf_deserialize_SaNameT (tmp, &si->name);
 	tmp = amf_deserialize_SaNameT (tmp, &si->saAmfSIProtectedbySG);
@@ -626,7 +636,7 @@ struct amf_si *amf_si_deserialize (struct amf_application *app, char *buf)
 }
 
 /*****************************************************************************
- * SI Assignment class implementation                          *              
+ * SI Assignment class implementation                          *
  ****************************************************************************/
 
 struct amf_si_assignment *amf_si_assignment_new (struct amf_si *si)
@@ -680,7 +690,7 @@ struct amf_si *amf_si_find (struct amf_application *app, char *name)
 	struct amf_si *si;
 
 	for (si = app->si_head; si != NULL; si = si->next) {
-		if (si->name.length == strlen(name) && 
+		if (si->name.length == strlen(name) &&
 			strncmp (name, (char*)si->name.value, si->name.length) == 0) {
 			break;
 		}
@@ -747,12 +757,12 @@ struct amf_csi *amf_csi_deserialize (struct amf_si *si, char *buf)
 	return csi;
 }
 
-struct amf_csi *amf_csi_find (struct amf_si *si, char *name)
+struct amf_csi *amf_csi_find (struct amf_si *si, const char *name)
 {
 	struct amf_csi *csi;
 
 	for (csi = si->csi_head; csi != NULL; csi = csi->next) {
-		if (csi->name.length == strlen(name) && 
+		if (csi->name.length == strlen(name) &&
 			strncmp (name, (char*)csi->name.value, csi->name.length) == 0) {
 			break;
 		}
@@ -765,10 +775,10 @@ struct amf_csi *amf_csi_find (struct amf_si *si, char *name)
 }
 
 /*****************************************************************************
- * CSI Assignment class implementation                         *              
+ * CSI Assignment class implementation                         *
  ****************************************************************************/
 
-struct amf_csi_assignment *amf_csi_assignment_new (struct amf_csi *csi)
+static struct amf_csi_assignment *amf_csi_assignment_new (struct amf_csi *csi)
 {
 	struct amf_csi_assignment *csi_assignment =
 		amf_calloc (1, sizeof (struct amf_csi_assignment));
@@ -799,18 +809,18 @@ void *amf_csi_assignment_serialize (
 	return buf;
 }
 
-struct amf_si_assignment *si_assignment_find (
+static struct amf_si_assignment *si_assignment_find (
 	struct amf_csi_assignment *csi_assignment)
 {
 	struct amf_comp *component;
 	struct amf_si_assignment *si_assignment = NULL;
 
-	component = amf_comp_find(csi_assignment->csi->si->application->cluster, 
+	component = amf_comp_find(csi_assignment->csi->si->application->cluster,
 		&csi_assignment->name);
 
 	for (si_assignment = csi_assignment->csi->si->assigned_sis;
 		si_assignment != NULL; si_assignment = si_assignment->next) {
-		SaNameT su_name; 
+		SaNameT su_name;
 		amf_su_dn_make (component->su,&su_name);
 
 		if (name_match(&su_name, &si_assignment->name)) {
@@ -861,7 +871,7 @@ char *amf_csi_assignment_dn_make (
 }
 
 struct amf_csi_assignment *amf_csi_assignment_find (
-	struct amf_cluster *cluster, SaNameT *name)
+	struct amf_cluster *cluster, const SaNameT *name)
 {
 	struct amf_application *app;
 	struct amf_si *si;
@@ -918,7 +928,7 @@ struct amf_csi_assignment *amf_csi_assignment_find (
 	for (csi_assignment = csi->assigned_csis; csi_assignment != NULL;
 		csi_assignment = csi_assignment->next) {
 
-		if (csi_assignment->name.length == strlen(csi_assignment_name) && 
+		if (csi_assignment->name.length == strlen(csi_assignment_name) &&
 			strncmp (csi_assignment_name,
 			(char*)csi_assignment->name.value,
 			csi_assignment->name.length) == 0) {
@@ -1007,7 +1017,7 @@ void amf_si_assignment_remove (amf_si_assignment_t *si_assignment,
 		for (csi_assignment = csi->assigned_csis; csi_assignment != NULL;
 			csi_assignment = csi_assignment->next) {
 
-			/* 
+			/*
 			 * If the CSI assignment and the SI assignment belongs to the
 			 * same SU, we have a match and can request the component to
 			 * remove the CSI.
@@ -1022,7 +1032,7 @@ void amf_si_assignment_remove (amf_si_assignment_t *si_assignment,
 		}
 	}
 
-	/*                                                              
+	/*
 	 * If the SU has only one component which is the faulty one, we
 	 * will not get an asynchronous response from the component.
 	 * This response (amf_si_comp_set_ha_state_done) is used to do
@@ -1044,7 +1054,7 @@ void amf_si_comp_csi_removed (
 
 	csi_assignment->saAmfCSICompHAState = USR_AMF_HA_STATE_REMOVED;
 
-	/*                                                              
+	/*
      * Report to caller when all requested CSI assignments has
      * been removed.
 	 */
@@ -1053,4 +1063,3 @@ void amf_si_comp_csi_removed (
 			csi_assignment->si_assignment);
 	}
 }
-
