@@ -6,7 +6,7 @@
  * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -32,6 +32,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -118,7 +119,7 @@ void CSISetCallback (
 {
 	switch (*haState) {
 	case SA_AMF_ACTIVE:
-		printf ("CSISetCallback: '"); 
+		printf ("CSISetCallback: '");
 		printSaNameT ((SaNameT *)compName);
 		printf ("' for CSI '");
 		printSaNameT ((SaNameT *)compName);
@@ -127,7 +128,7 @@ void CSISetCallback (
 		saAmfResponse (invocation, SA_OK);
 		break;
 	case SA_AMF_STANDBY:
-		printf ("CSISetCallback: '"); 
+		printf ("CSISetCallback: '");
 		printSaNameT ((SaNameT *)compName);
 		printf ("' for CSI '");
 		printSaNameT ((SaNameT *)compName);
@@ -136,7 +137,7 @@ void CSISetCallback (
 		saAmfResponse (invocation, SA_OK);
 		break;
 	case SA_AMF_QUIESCED:
-		printf ("CSISetCallback: '"); 
+		printf ("CSISetCallback: '");
 		printSaNameT ((SaNameT *)compName);
 		printf ("' for CSI '");
 		printSaNameT ((SaNameT *)compName);
