@@ -1,7 +1,7 @@
 #define _BSD_SOURCE
 /*
  * Copyright (c) 2002-2004 MontaVista Software, Inc.
- * Copyright (c) 2006-2007 Red Hat, Inc.
+ * Copyright (c) 2006-2007, 2009 Red Hat, Inc.
  * Copyright (c) 2006 Sun Microsystems, Inc.
  *
  * All rights reserved.
@@ -9,7 +9,7 @@
  * Author: Steven Dake (sdake@sdake.com)
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -35,6 +35,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -50,7 +51,7 @@
 #include "saCkpt.h"
 #include "sa_error.h"
 
-#ifdef OPENAIS_SOLARIS
+#ifndef timersub
 #define timersub(a, b, result)						\
     do {								\
 	(result)->tv_sec = (a)->tv_sec - (b)->tv_sec;			\
@@ -64,24 +65,16 @@
 
 #define SECONDS_TO_EXPIRE 5
 
-int ckptinv;
-SaInvocationT open_invocation = 16;
-void printSaNameT (SaNameT *name)
-{
-	int i;
+static int ckptinv;
+static SaInvocationT open_invocation = 16;
 
-	for (i = 0; i < name->length; i++) {
-		printf ("%c", name->value[i]);
-	}
-}
+static SaVersionT version = { 'B', 1, 1 };
 
-SaVersionT version = { 'B', 1, 1 };
+static SaNameT defaultCheckpointName = { 8, "defaults" };
 
-SaNameT defaultCheckpointName = { 8, "defaults" };
+static SaNameT sectionsCheckpointName = { 8, "sections" };
 
-SaNameT sectionsCheckpointName = { 8, "sections" };
-
-SaCkptCheckpointCreationAttributesT checkpointCreationAttributes = {
+static SaCkptCheckpointCreationAttributesT checkpointCreationAttributes = {
 	.creationFlags = SA_CKPT_WR_ALL_REPLICAS,
 	.checkpointSize = 100000,
 	.retentionDuration = 5000000000LL,
@@ -90,33 +83,33 @@ SaCkptCheckpointCreationAttributesT checkpointCreationAttributes = {
 	.maxSectionIdSize = 20
 };
 
-SaCkptSectionIdT sectionId1 = {
+static SaCkptSectionIdT sectionId1 = {
 	13,
 	(SaUint8T *) "section ID #1"
 };
 
-SaCkptSectionIdT sectionId2 = {
+static SaCkptSectionIdT sectionId2 = {
 	13,
 	(SaUint8T *) "section ID #2"
 };
 
-SaCkptSectionCreationAttributesT sectionCreationAttributes1 = {
+static SaCkptSectionCreationAttributesT sectionCreationAttributes1 = {
 	&sectionId1,
 	SA_TIME_END
 };
 
-SaCkptSectionCreationAttributesT sectionCreationAttributes2 = {
+static SaCkptSectionCreationAttributesT sectionCreationAttributes2 = {
 	&sectionId2,
 	SA_TIME_END
 };
 
-char readBuffer1[1025];
+static char readBuffer1[1025];
 
-char readBuffer2[1025];
+static char readBuffer2[1025];
 
-char default_read_buffer[1025];
+static char default_read_buffer[1025];
 
-SaCkptIOVectorElementT ReadVectorElements[] = {
+static SaCkptIOVectorElementT ReadVectorElements[] = {
 	{
 		{
 			13,
@@ -124,7 +117,7 @@ SaCkptIOVectorElementT ReadVectorElements[] = {
 		},
 		readBuffer1,
 		sizeof (readBuffer1),
-		0, 
+		0,
 		0
 	},
 	{
@@ -134,12 +127,12 @@ SaCkptIOVectorElementT ReadVectorElements[] = {
 		},
 		readBuffer2,
 		sizeof (readBuffer2),
-		0, 
+		0,
 		0
 	}
 };
 
-SaCkptIOVectorElementT default_read_vector[] = {
+static SaCkptIOVectorElementT default_read_vector[] = {
 	{
 		SA_CKPT_DEFAULT_SECTION_ID,
         default_read_buffer, /*"written data #1, this should extend past end of old section data", */
@@ -151,10 +144,10 @@ SaCkptIOVectorElementT default_read_vector[] = {
 
 
 #define DATASIZE 127000
-char data1[DATASIZE];
-char data2[DATASIZE];
-char default_write_data[56];
-SaCkptIOVectorElementT WriteVectorElements[] = {
+static char data1[DATASIZE];
+static char data2[DATASIZE];
+static char default_write_data[56];
+static SaCkptIOVectorElementT WriteVectorElements[] = {
 	{
 		{
 			13,
@@ -162,7 +155,7 @@ SaCkptIOVectorElementT WriteVectorElements[] = {
 		},
 		data1, /*"written data #1, this should extend past end of old section data", */
 		DATASIZE, /*sizeof ("data #1, this should extend past end of old section data") + 1, */
-		0, //5, 
+		0, //5,
 		0
 	},
 	{
@@ -172,7 +165,7 @@ SaCkptIOVectorElementT WriteVectorElements[] = {
 		},
 		data2, /*"written data #2, this should extend past end of old section data" */
 		DATASIZE, /*sizeof ("written data #2, this should extend past end of old section data") + 1, */
-		0, //3, 
+		0, //3,
 		0
 	}
 };
@@ -180,32 +173,40 @@ SaCkptIOVectorElementT WriteVectorElements[] = {
 SaCkptIOVectorElementT default_write_vector[] = {
 	{
 		SA_CKPT_DEFAULT_SECTION_ID,
-		default_write_data, /*"written data #1, this should extend past end of old section data", */	
+		default_write_data, /*"written data #1, this should extend past end of old section data", */
 		56, /*sizeof ("data #1, this should extend past end of old section data") + 1, */
 		0, //5,
 		0
 	}
 };
 
-SaCkptCheckpointHandleT checkpointHandle;
+static SaCkptCheckpointHandleT checkpointHandle;
 
-void OpenCallBack (
+static void OpenCallBack (
     SaInvocationT invocation,
     const SaCkptCheckpointHandleT chckpointHandle,
     SaAisErrorT error) {
-	
+
  	printf ("%s: This is a call back for open for invocation = %d\n",
-		get_test_output (error, SA_AIS_OK), (int)invocation);	
+		get_test_output (error, SA_AIS_OK), (int)invocation);
 
 	checkpointHandle = chckpointHandle;
 
 }
 
-SaCkptCallbacksT callbacks = {
+static SaCkptCallbacksT callbacks = {
  	&OpenCallBack,
 	0
 };
 
+static char *print_section_id (SaCkptSectionIdT *section_id)
+{
+	static char ret_buf[128];
+	memcpy (ret_buf, section_id->id, section_id->idLen);
+	ret_buf[section_id->idLen] = '\0';
+	return (ret_buf);
+}
+
 int main (void) {
 	SaCkptHandleT ckptHandle;
 	SaCkptCheckpointHandleT checkpointHandle2;
@@ -221,7 +222,7 @@ int main (void) {
 	SaSelectionObjectT sel_fd;
 	fd_set read_set;
 	int i;
-	
+
 	error = saCkptInitialize (&ckptHandle, &callbacks, &version);
 	printf ("%s: checkpoint initialize\n",
 		get_test_output (error, SA_AIS_OK));
@@ -243,14 +244,14 @@ int main (void) {
 	select (sel_fd + 1, &read_set, 0, 0, 0);
 
 	error = saCkptDispatch (ckptHandle, SA_DISPATCH_ALL);
-	
+
 	printf ("%s: Dispatch response for open async of checkpoint\n",
 		get_test_output (error, SA_AIS_OK));
 
 	error = saCkptCheckpointClose (checkpointHandle);
 
 	printf ("%s: Closing checkpoint\n", get_test_output (error, SA_AIS_OK));
-	
+
 	error = saCkptCheckpointOpen (ckptHandle,
 		&defaultCheckpointName,
 		&checkpointCreationAttributes,
@@ -288,7 +289,7 @@ int main (void) {
 		get_test_output (error, SA_AIS_OK));
 
 	printf (" default_read_buffer:'%s'\n", default_read_buffer);
-	
+
 	error = saCkptCheckpointClose (checkpointHandle);
 
 	checkpointCreationAttributes.maxSections = 5;
@@ -358,7 +359,7 @@ sleep (1);
 		get_test_output (error, SA_AIS_OK));
 
 	error = saCkptCheckpointUnlink (ckptHandle, &sectionsCheckpointName);
-	printf ("%s: Unlinking checkpoint\n", 
+	printf ("%s: Unlinking checkpoint\n",
 		get_test_output (error, SA_AIS_OK));
 
 	error = saCkptCheckpointOpen (ckptHandle,
@@ -367,11 +368,11 @@ sleep (1);
 		SA_CKPT_CHECKPOINT_CREATE|SA_CKPT_CHECKPOINT_READ|SA_CKPT_CHECKPOINT_WRITE,
 		0,
 		&checkpointHandle2);
-	printf ("%s: Opening unlinked checkpoint\n", 
+	printf ("%s: Opening unlinked checkpoint\n",
 		get_test_output (error, SA_AIS_OK));
 
 	error = saCkptCheckpointClose (checkpointHandle);
-	printf ("%s: Closing checkpoint\n", 
+	printf ("%s: Closing checkpoint\n",
 		get_test_output (error, SA_AIS_OK));
 
 	error = saCkptCheckpointOpen (ckptHandle,
@@ -407,7 +408,7 @@ sleep (1);
 		printf ("Memory used %d in %d sections.\n", (int)checkpointStatus.memoryUsed,
 			(int)checkpointStatus.numberOfSections);
 	}
-	
+
 	error = saCkptSectionCreate (checkpointHandleRead,
 		&sectionCreationAttributes1,
 		"Initial Data #0",
@@ -423,19 +424,19 @@ sleep (1);
 		strlen ("Initial Data #0") + 1);
 	printf ("%s: Create checkpoint section on writeable checkpoint\n",
 		get_test_output (error, SA_AIS_OK));
-		
+
 	error = saCkptSectionCreate (checkpointHandle,
 		&sectionCreationAttributes1,
 		"Initial Data #0",
 		strlen ("Initial Data #0") + 1);
 	printf ("%s: Create checkpoint section when one already exists\n",
 		get_test_output (error, SA_AIS_ERR_EXIST));
-		
+
 	error = saCkptSectionDelete (checkpointHandle,
 		&sectionId1);
 	printf ("%s: deleting section handle\n",
 		get_test_output (error, SA_AIS_OK));
-		
+
 	error = saCkptSectionCreate (checkpointHandle,
 		&sectionCreationAttributes1,
 		"Initial Data #0",
@@ -461,7 +462,7 @@ sleep (1);
 		SA_TIME_END);
 	printf ("%s: Setting expiration time for section 2\n",
 		get_test_output (error, SA_AIS_OK));
-		
+
 	error = saCkptSectionOverwrite (checkpointHandle,
 		&sectionId1,
 		"Overwrite Data #1",
@@ -547,7 +548,7 @@ sleep (1);
 		}
 		if (error == SA_AIS_OK) {
 			printf ("Section '%s' expires %llx size %llu state %x update %llx\n",
-				sectionDescriptor.sectionId.id,
+				print_section_id (&sectionDescriptor.sectionId),
 				(unsigned long long)sectionDescriptor.expirationTime,
 				(unsigned long long)sectionDescriptor.sectionSize,
 				sectionDescriptor.sectionState,
