@@ -7,7 +7,7 @@
  * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -33,6 +33,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,7 +48,7 @@
 #include "saAis.h"
 #include "saClm.h"
 
-void printSaClmNodeAddressT (SaClmNodeAddressT *nodeAddress) {
+static void printSaClmNodeAddressT (const SaClmNodeAddressT *nodeAddress) {
 	int i;
 
 	printf ("family=%d - address=", nodeAddress->family);
@@ -56,7 +57,7 @@ void printSaClmNodeAddressT (SaClmNodeAddressT *nodeAddress) {
 	}
 }
 
-void printSaNameT (SaNameT *name)
+static void printSaNameT (SaNameT *name)
 {
 	int i;
 
@@ -65,7 +66,7 @@ void printSaNameT (SaNameT *name)
 	}
 }
 
-void printSaClmClusterNodeT (char *description, SaClmClusterNodeT *clusterNode) {
+static void printSaClmClusterNodeT (const char *description, SaClmClusterNodeT *clusterNode) {
 	printf ("Node Information for %s\n", description);
 
 	printf ("\tnode id is %x\n", (int)clusterNode->nodeId);
@@ -83,10 +84,10 @@ void printSaClmClusterNodeT (char *description, SaClmClusterNodeT *clusterNode)
 	printf ("\tTimestamp is %llx nanoseconds\n", (unsigned long long)clusterNode->bootTimestamp);
 }
 
-void NodeGetCallback (
+static void NodeGetCallback (
 	SaInvocationT invocation,
 	const SaClmClusterNodeT *clusterNode,
-	SaAisErrorT error) 
+	SaAisErrorT error)
 {
 	char buf[128];
 
@@ -99,7 +100,7 @@ void NodeGetCallback (
 	}
 }
 
-void TrackCallback (
+static void TrackCallback (
 	const SaClmClusterNotificationBufferT *notificationBuffer,
 	SaUint32T numberOfMembers,
 	SaAisErrorT error)
@@ -129,14 +130,14 @@ printf ("Track callback\n");
 	printf ("Done calling trackCallback\n");
 }
 
-SaClmCallbacksT callbacks = {
+static SaClmCallbacksT callbacks = {
 	.saClmClusterNodeGetCallback	= NodeGetCallback,
 	.saClmClusterTrackCallback		= TrackCallback
 };
 
-SaVersionT version = { 'B', 1, 1 };
+static SaVersionT version = { 'B', 1, 1 };
 
-void sigintr_handler (int signum) {
+static void sigintr_handler (int signum) {
 	exit (0);
 }
 
