@@ -5,7 +5,7 @@
  * All rights reserved.
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -33,7 +33,7 @@
 
 /*
  * Test program for event service
- * 
+ *
  *	test_initialize ();
  *		Version check in saEvtInitialze()
  *
@@ -56,6 +56,7 @@
  *		Test event channel unlink.
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -71,29 +72,29 @@ int result_buf_len = sizeof(result_buf);
 #define TRY_WAIT 2
 
 
-void testresult (SaAisErrorT result, SaAisErrorT expected, int test_no)
+static void testresult (SaAisErrorT result, SaAisErrorT expected, int test_no)
 {
 	if (result == expected) {
 		printf ("Test %d passed\n", test_no);
 	} else {
 		get_sa_error(result, result_buf, result_buf_len);
-		printf ("ERROR: Test %d FAILED (expected %d got %s)\n", 
+		printf ("ERROR: Test %d FAILED (expected %d got %s)\n",
 						test_no, expected, result_buf);
 	}
 }
 
-SaVersionT version1 = { 'B', 0x01, 0x01 };
-SaVersionT version2 = { 'A', 0x01, 0x01 };
-SaVersionT version3 = { 'B', 0x02, 0x01 };
-SaVersionT version4 = { 'B', 0x01, 0xff };
-SaVersionT version5 = { 'C', 0xff, 0xff };
+static SaVersionT version1 = { 'B', 0x01, 0x01 };
+static SaVersionT version2 = { 'A', 0x01, 0x01 };
+static SaVersionT version3 = { 'B', 0x02, 0x01 };
+static SaVersionT version4 = { 'B', 0x01, 0xff };
+static SaVersionT version5 = { 'C', 0xff, 0xff };
 
 struct version_test {
 	SaVersionT	*version;
 	SaAisErrorT	result;
 };
 
-struct version_test versions[] = {
+static struct version_test versions[] = {
 	{ &version1, SA_AIS_OK },
 	{ &version2, SA_AIS_ERR_VERSION },
 	{ &version3, SA_AIS_ERR_VERSION },
@@ -102,39 +103,39 @@ struct version_test versions[] = {
 	{ 0, SA_AIS_ERR_INVALID_PARAM}
 };
 
-int version_size = sizeof(versions) / sizeof(struct version_test);
+static int version_size = sizeof(versions) / sizeof(struct version_test);
 
-void open_callback(SaInvocationT invocation,
+static void open_callback(SaInvocationT invocation,
 		SaEvtChannelHandleT channelHandle,
 		SaAisErrorT error);
-void event_callback(SaEvtSubscriptionIdT subscriptionId,
+static void event_callback(SaEvtSubscriptionIdT subscriptionId,
 		const SaEvtEventHandleT eventHandle,
 		const SaSizeT eventDataSize);
 
-SaEvtCallbacksT callbacks = {
+static SaEvtCallbacksT callbacks = {
 	open_callback,
 	event_callback
 };
 
-char channel[256] = "TESTEVT_CHANNEL";
-char unlink_channel[256] = "TESTEVT_UNLINK_CHANNEL";
-SaEvtSubscriptionIdT subscription_id = 0xabcdef;
-SaInvocationT	     open_invocation = 0xaa55cc33;
-unsigned long long test_ret_time = 30000000000ULL; /* 30 seconds */
+static char channel[256] = "TESTEVT_CHANNEL";
+static char unlink_channel[256] = "TESTEVT_UNLINK_CHANNEL";
+static SaEvtSubscriptionIdT subscription_id = 0xabcdef;
+static SaInvocationT	     open_invocation = 0xaa55cc33;
+static unsigned long long test_ret_time = 30000000000ULL; /* 30 seconds */
 
 
 /*
  * event data
  */
 
-long *exp_data;
+static long *exp_data;
 #define DATA_SIZE 2048 /* default data size */
 #define LCOUNT DATA_SIZE/sizeof(long)
-	
+
 /*
  * Test saEvtInitialize and version checking.
  */
-void test_initialize (void) {
+static void test_initialize (void) {
 	SaAisErrorT result;
 	SaEvtHandleT handle;
 	int i;
@@ -175,22 +176,22 @@ void test_initialize (void) {
 #define patt4_size sizeof(_patt4)
 
 
-SaEvtEventFilterT filters[] = {
+static SaEvtEventFilterT filters[] = {
 	{SA_EVT_PREFIX_FILTER, {patt1_size, patt1_size, patt1}},
 	{SA_EVT_SUFFIX_FILTER, {patt2_size, patt2_size, patt2}},
 	{SA_EVT_EXACT_FILTER, {patt3_size, patt3_size, patt3}},
 	{SA_EVT_PASS_ALL_FILTER, {patt4_size, patt4_size, patt4}}
 };
 
-SaEvtEventFilterArrayT subscribe_filters = {
+static SaEvtEventFilterArrayT subscribe_filters = {
 	sizeof(filters)/sizeof(SaEvtEventFilterT),
-	filters 
+	filters
 };
 
 /*
  * Process the open callback
  */
-void open_callback(SaInvocationT invocation,
+static void open_callback(SaInvocationT invocation,
 		SaEvtChannelHandleT channel_handle,
 		SaAisErrorT error)
 {
@@ -211,7 +212,7 @@ void open_callback(SaInvocationT invocation,
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result: %s\n", result_buf);
@@ -229,10 +230,10 @@ void open_callback(SaInvocationT invocation,
  * 7. Duplicate subscription ID.
  * 8. unsubscribe non-exsistent subscription ID.
  * 9. Open a channel async.
- * 
+ *
  */
-void
-test_channel()
+static void
+test_channel(void)
 {
 	SaEvtHandleT handle;
 	SaEvtChannelHandleT channel_handle;
@@ -244,7 +245,7 @@ test_channel()
 	int nfd;
 	SaSelectionObjectT fd;
 	int timeout = 5000;
-	 
+
 	flags = SA_EVT_CHANNEL_PUBLISHER |
 		SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
@@ -257,7 +258,7 @@ test_channel()
 
 	printf("       Channel open:\n");
 	do {
-		result = saEvtInitialize (&handle, 
+		result = saEvtInitialize (&handle,
 				&callbacks, versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 
@@ -290,7 +291,7 @@ test_channel()
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result: %s\n", result_buf);
@@ -306,13 +307,13 @@ test_channel()
 		printf("ERROR: Event Finalize result: %s\n", result_buf);
 		return;
 	}
-	
+
 	/*
 	 * Test channel subscribe
 	 */
 	printf("       Channel subscribe:\n");
 	do {
-		result = saEvtInitialize (&handle, &callbacks, 
+		result = saEvtInitialize (&handle, &callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -408,7 +409,7 @@ test_channel()
 	 */
 	printf("       Channel subscribe with no close at end:\n");
 	do {
-		result = saEvtInitialize (&handle, &callbacks, 
+		result = saEvtInitialize (&handle, &callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -453,7 +454,7 @@ test_channel()
 	 */
 	printf("       Multiple subscriptions\n");
 	do {
-		result = saEvtInitialize (&handle, &callbacks, 
+		result = saEvtInitialize (&handle, &callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -555,7 +556,7 @@ test_channel()
 	printf("       Unsubscribe non-existent sub_id\n");
 
 	do {
-		result = saEvtEventUnsubscribe(channel_handle, 
+		result = saEvtEventUnsubscribe(channel_handle,
 				subscription_id+2);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_ERR_NOT_EXIST) {
@@ -586,7 +587,7 @@ test_channel()
 		printf("ERROR: first event unsubscribe result: %s\n", result_buf);
 	}
 	do {
-		result = saEvtEventUnsubscribe(channel_handle, 
+		result = saEvtEventUnsubscribe(channel_handle,
 				subscription_id+1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -613,7 +614,7 @@ test_channel()
 	 */
 	printf("       Channel open async:\n");
 	do {
-		result = saEvtInitialize (&handle, &callbacks, 
+		result = saEvtInitialize (&handle, &callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 
@@ -624,7 +625,7 @@ test_channel()
 	}
 
 	do {
-		result = saEvtChannelOpenAsync(handle, open_invocation, 
+		result = saEvtChannelOpenAsync(handle, open_invocation,
 			&channel_name, flags);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 
@@ -692,47 +693,47 @@ test_channel()
 
 }
 
-	SaUint8T pat0[100];
-	SaUint8T pat1[100];
-	SaUint8T pat2[100];
-	SaUint8T pat3[100];
-	SaUint8T pat4[100];
-	SaEvtEventPatternT evt_patts[5] = {
-		{100, 100, pat0},
-		{100, 100, pat1},
-		{100, 100, pat2},
-		{100, 100, pat3},
-		{100, 100, pat4}};
-	SaEvtEventPatternArrayT	evt_pat_get_array = { 5, 0, evt_patts };
+static SaUint8T pat0_[100];
+static SaUint8T pat1_[100];
+static SaUint8T pat2_[100];
+static SaUint8T pat3_[100];
+static SaUint8T pat4_[100];
+static SaEvtEventPatternT evt_patts[5] = {
+		{100, 100, pat0_},
+		{100, 100, pat1_},
+		{100, 100, pat2_},
+		{100, 100, pat3_},
+		{100, 100, pat4_}};
+static SaEvtEventPatternArrayT evt_pat_get_array = { 5, 0, evt_patts };
 
-SaEvtEventPatternT patterns[] = {
+static SaEvtEventPatternT patterns[] = {
 	{patt1_size, patt1_size, patt1},
 	{patt2_size, patt2_size, patt2},
 	{patt3_size, patt3_size, patt3},
 	{patt4_size, patt4_size, patt4}
 };
-SaNameT test_pub_name = {13, "Test Pub Name"};
+static SaNameT test_pub_name = {13, "Test Pub Name"};
 #define TEST_PRIORITY 2
 
-SaEvtEventPatternArrayT evt_pat_set_array = {
+static SaEvtEventPatternArrayT evt_pat_set_array = {
 	sizeof(patterns)/sizeof(SaEvtEventPatternT),
 	sizeof(patterns)/sizeof(SaEvtEventPatternT),
 	patterns
 };
 
-char event_data[1000];
+static char event_data[1000];
 #define EVENT_DATA_SIZE 1000
 
-SaEvtEventIdT event_id = 0;
-SaUint8T priority;
-SaTimeT retention_time = 0ULL;
-SaNameT publisher_name = {0, {0}};
-SaSizeT event_data_size = 0;
-int expected_pat_count;
+static SaEvtEventIdT event_id = 0;
+static SaUint8T priority;
+static SaTimeT retention_time = 0ULL;
+static SaNameT publisher_name = {0, {0}};
+static SaSizeT event_data_size = 0;
+static int expected_pat_count;
 
 /*
  * Test event operations.
- * 
+ *
  * 1. Event allocation
  * 2. Get event attributes (no pointers).
  * 3. Get event attributes with pointers.
@@ -745,9 +746,9 @@ int expected_pat_count;
  * 10. Free event.
  * 11. Publish with no set patterns.
  * 12. Publish with set patterns and event user data.
- * 
+ *
  */
-void 
+static void
 event_callback(SaEvtSubscriptionIdT my_subscription_id,
 		const SaEvtEventHandleT event_handle,
 		const SaSizeT my_event_data_size)
@@ -764,11 +765,11 @@ event_callback(SaEvtSubscriptionIdT my_subscription_id,
 
 	printf("       event_callback called\n");
 	if (my_subscription_id != subscription_id) {
-		printf("ERROR: sub ID: e=%x, a=%x\n", 
+		printf("ERROR: sub ID: e=%x, a=%x\n",
 				subscription_id, my_subscription_id);
 	}
 	if (my_event_data_size != event_data_size) {
-		printf("ERROR: event data size e=%llu, a=%llu\n", 
+		printf("ERROR: event data size e=%llu, a=%llu\n",
 				(unsigned long long)event_data_size,
 				(unsigned long long)my_event_data_size);
 	}
@@ -796,7 +797,7 @@ event_callback(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if (evt_pat_get_array.patternsNumber != expected_pat_count) {
-		printf("ERROR: pattern array count not %d: %llu\n", 
+		printf("ERROR: pattern array count not %d: %llu\n",
 					expected_pat_count,
 					(unsigned long long)evt_pat_get_array.patternsNumber);
 	}
@@ -830,24 +831,24 @@ event_callback(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if (priority != my_priority) {
-		printf("ERROR: priority: e=0x%x a=0x%x\n", 
+		printf("ERROR: priority: e=0x%x a=0x%x\n",
 				priority, my_priority);
 	}
 	if (retention_time != my_retention_time) {
-		printf("ERROR: retention: e=0x%llx a=0x%llx\n", 
+		printf("ERROR: retention: e=0x%llx a=0x%llx\n",
 			(unsigned long long)retention_time,
 			(unsigned long long)my_retention_time);
 	}
 	if (publisher_name.length != my_publisher_name.length) {
-		printf("ERROR: publisher name length: e=%d, a=%d\n", 
+		printf("ERROR: publisher name length: e=%d, a=%d\n",
 		publisher_name.length,
-		my_publisher_name.length); 
+		my_publisher_name.length);
 	} else {
 		if (memcmp(publisher_name.value, my_publisher_name.value,
 					publisher_name.length) != 0) {
-			printf("ERROR: publisher name content: e=%s, a=%s\n", 
+			printf("ERROR: publisher name content: e=%s, a=%s\n",
 			publisher_name.value,
-			my_publisher_name.value); 
+			my_publisher_name.value);
 		}
 	}
 
@@ -863,7 +864,7 @@ event_callback(SaEvtSubscriptionIdT my_subscription_id,
 		goto dat_free;
 	}
 	if (data_size != event_data_size) {
-		printf("ERROR: Data size: e=%llu a=%llu\n", 
+		printf("ERROR: Data size: e=%llu a=%llu\n",
 				(unsigned long long)event_data_size,
 				(unsigned long long)data_size);
 	}
@@ -887,8 +888,8 @@ evt_free:
 	}
 }
 
-void
-test_event()
+static void
+test_event(void)
 {
 	SaEvtHandleT handle;
 	SaEvtChannelHandleT channel_handle;
@@ -903,12 +904,12 @@ test_event()
 	int timeout = 5000;
 
 
-	
+
 	SaAisErrorT result;
 
 	int i;
-	 
-	flags = SA_EVT_CHANNEL_PUBLISHER|SA_EVT_CHANNEL_SUBSCRIBER | 
+
+	flags = SA_EVT_CHANNEL_PUBLISHER|SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
 	strcpy((char *)channel_name.value, channel);
 	channel_name.length = strlen(channel);
@@ -985,7 +986,7 @@ test_event()
 		goto evt_free;
 	}
 	if (evt_pat_get_array.patternsNumber != 0) {
-		printf("ERROR: pattern array count not zero: %llu\n", 
+		printf("ERROR: pattern array count not zero: %llu\n",
 					(unsigned long long)evt_pat_get_array.patternsNumber);
 	}
 	if (priority != SA_EVT_LOWEST_PRIORITY) {
@@ -1038,7 +1039,7 @@ test_event()
 		goto evt_free;
 	}
 	if (evt_pat_get_array.patternsNumber != 4) {
-		printf("ERROR: pattern array count not 4: %llu\n", 
+		printf("ERROR: pattern array count not 4: %llu\n",
 					(unsigned long long)evt_pat_get_array.patternsNumber);
 	}
 	for (i = 0; i < evt_pat_get_array.patternsNumber; i++) {
@@ -1066,24 +1067,24 @@ test_event()
 	}
 
 	if (priority != TEST_PRIORITY) {
-		printf("ERROR: priority: e=0x%x a=0x%x\n", 
+		printf("ERROR: priority: e=0x%x a=0x%x\n",
 				TEST_PRIORITY, priority);
 	}
 	if (retention_time != test_ret_time) {
-		printf("ERROR: retention: e=0x%llx a=0x%llx\n", 
+		printf("ERROR: retention: e=0x%llx a=0x%llx\n",
 			(unsigned long long)test_ret_time,
 			(unsigned long long)retention_time);
 	}
 	if (publisher_name.length != test_pub_name.length) {
-		printf("ERROR: publisher name length: e=%d, a=%d\n", 
+		printf("ERROR: publisher name length: e=%d, a=%d\n",
 		test_pub_name.length,
-		publisher_name.length); 
+		publisher_name.length);
 	} else {
 		if (memcmp(publisher_name.value, test_pub_name.value,
 					publisher_name.length) != 0) {
-			printf("ERROR: publisher name content: e=%s, a=%s\n", 
+			printf("ERROR: publisher name content: e=%s, a=%s\n",
 			test_pub_name.value,
-			publisher_name.value); 
+			publisher_name.value);
 		}
 	}
 
@@ -1124,7 +1125,7 @@ test_event()
 	printf("       Get event data(4)\n");
 	event_data_size = EVENT_DATA_SIZE;
 	do {
-		result = saEvtEventDataGet(event_handle, event_data, 
+		result = saEvtEventDataGet(event_handle, event_data,
 				&event_data_size);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_ERR_BAD_HANDLE) {
@@ -1134,7 +1135,7 @@ test_event()
 	printf("       Get event data(5)\n");
 	event_data_size = 1;
 	do {
-		result = saEvtEventDataGet(event_handle, event_data, 
+		result = saEvtEventDataGet(event_handle, event_data,
 				&event_data_size);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_ERR_BAD_HANDLE) {
@@ -1271,7 +1272,7 @@ test_event()
 	 * Send it
 	 */
 	do {
-		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE,
 								&event_id);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1332,7 +1333,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result: %s\n", result_buf);
@@ -1362,7 +1363,7 @@ static int call_count = 0;
  * Checks event ID with subscription ID to make sure that we
  * received an event on the correct subscription.
  */
-void 
+static void
 multi_test_callback1(SaEvtSubscriptionIdT my_subscription_id,
 		const SaEvtEventHandleT event_handle,
 		const SaSizeT my_event_data_size)
@@ -1408,13 +1409,13 @@ multi_test_callback1(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if (my_subscription_id != exp_sub_id) {
-		printf("ERROR: sub ID: e=%x, a=%x\n", 
+		printf("ERROR: sub ID: e=%x, a=%x\n",
 				exp_sub_id, my_subscription_id);
 		goto evt_free;
 	}
 
 	if (evt_pat_get_array.patternsNumber != 1) {
-		printf("ERROR: pattern array count not 1: %lld\n", 
+		printf("ERROR: pattern array count not 1: %lld\n",
 					(unsigned long long)evt_pat_get_array.patternsNumber);
 	}
 
@@ -1435,8 +1436,8 @@ evt_free:
  * 2. Test multiple openings of a single channel and receving events.
  * 3. Test opening of multiple channels and receiving events
  */
-void
-test_multi_channel1()
+static void
+test_multi_channel1(void)
 {
 
 	SaEvtEventFilterT filt1[1] = {
@@ -1475,9 +1476,9 @@ test_multi_channel1()
 	int timeout = 5000;
 
 
-	
+
 	SaAisErrorT result;
-	 
+
 	flags = SA_EVT_CHANNEL_PUBLISHER|SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
 	strcpy((char *)channel_name.value, channel);
@@ -1486,7 +1487,7 @@ test_multi_channel1()
 	printf("Test multiple operations:\n");
 
 	do {
-	result = saEvtInitialize (&handle, &multi_callbacks, 
+	result = saEvtInitialize (&handle, &multi_callbacks,
 			versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1569,7 +1570,7 @@ test_multi_channel1()
 	}
 
 	do {
-		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE,
 								&event_id1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1593,7 +1594,7 @@ test_multi_channel1()
 	}
 
 	do {
-		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE,
 								&event_id2);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1617,7 +1618,7 @@ test_multi_channel1()
 	}
 
 	do {
-		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE,
 								&event_id3);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1684,7 +1685,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result: %s\n", result_buf);
@@ -1708,7 +1709,7 @@ evt_fin:
  * each subscription.
  *
  */
-void 
+static void
 multi_test_callback2(SaEvtSubscriptionIdT my_subscription_id,
 		const SaEvtEventHandleT event_handle,
 		const SaSizeT my_event_data_size)
@@ -1765,7 +1766,7 @@ multi_test_callback2(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if (evt_pat_get_array.patternsNumber != 1) {
-		printf("ERROR: pattern array count not 1: %llu\n", 
+		printf("ERROR: pattern array count not 1: %llu\n",
 					(unsigned long long)evt_pat_get_array.patternsNumber);
 	}
 
@@ -1779,8 +1780,8 @@ evt_free:
 	}
 }
 
-void
-test_multi_channel2()
+static void
+test_multi_channel2(void)
 {
 
 	SaEvtEventFilterT filt1[1] = {
@@ -1815,9 +1816,9 @@ test_multi_channel2()
 	int timeout = 5000;
 
 
-	
+
 	SaAisErrorT result;
-	 
+
 	flags = SA_EVT_CHANNEL_PUBLISHER|SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
 	strcpy((char *)channel_name.value, channel);
@@ -1827,12 +1828,12 @@ test_multi_channel2()
  * 2. Test multiple openings of a single channel and receving events.
  *
  * 		Open and subscribe to a channel twice.  When an event is sent, it
- * 		should be delivered twice, once for each open channel.  
+ * 		should be delivered twice, once for each open channel.
  */
 	printf("Test multiple opens/subscribes:\n");
 
 	do {
-		result = saEvtInitialize (&handle, &multi_callbacks, 
+		result = saEvtInitialize (&handle, &multi_callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1908,7 +1909,7 @@ test_multi_channel2()
 	}
 
 	do {
-		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE,
 								&event_id1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -1976,7 +1977,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result(0): %s\n", result_buf);
@@ -1984,7 +1985,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result(1): %s\n", result_buf);
@@ -2004,11 +2005,11 @@ evt_fin:
 
 /*
  * Handle call back for multi-test3
- * Verifies that the event recevied is associated with the correct 
+ * Verifies that the event recevied is associated with the correct
  * subscription.
  *
  */
-void 
+static void
 multi_test_callback3(SaEvtSubscriptionIdT my_subscription_id,
 		const SaEvtEventHandleT event_handle,
 		const SaSizeT my_event_data_size)
@@ -2040,7 +2041,7 @@ multi_test_callback3(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if ((my_subscription_id != sub1) && (my_subscription_id != sub2)) {
-		printf("ERROR: Received wrong subscription ID %x\n", 
+		printf("ERROR: Received wrong subscription ID %x\n",
 				my_subscription_id);
 		printf("       sub1 %x, sub2 %x\n", sub1, sub2);
 		goto evt_free;
@@ -2065,7 +2066,7 @@ multi_test_callback3(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if (evt_pat_get_array.patternsNumber != 1) {
-		printf("ERROR: pattern array count not 1: %llu\n", 
+		printf("ERROR: pattern array count not 1: %llu\n",
 					(unsigned long long)evt_pat_get_array.patternsNumber);
 	}
 
@@ -2079,8 +2080,8 @@ evt_free:
 	}
 }
 
-void
-test_multi_channel3()
+static void
+test_multi_channel3(void)
 {
 
 	SaEvtEventFilterT filt1[1] = {
@@ -2118,9 +2119,9 @@ test_multi_channel3()
 	int timeout = 5000;
 
 
-	
+
 	SaAisErrorT result;
-	 
+
 	flags = SA_EVT_CHANNEL_PUBLISHER|SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
 	strcpy((char *)channel_name.value, channel);
@@ -2132,16 +2133,16 @@ test_multi_channel3()
 
 /*
  * 3. Test opening of multiple channels and receiving events.
- * 		Open and subscribe to two different channels twice.  
+ * 		Open and subscribe to two different channels twice.
  * 		Subscribe to each channel with the same filters.
- * 		Sending an event on one channel should be received in the 
- * 		call-back with the subscription ID corresponding to the sent 
+ * 		Sending an event on one channel should be received in the
+ * 		call-back with the subscription ID corresponding to the sent
  * 		channel.
  */
 	printf("Test multiple different channels/subscribes:\n");
 
 	do {
-		result = saEvtInitialize (&handle, &multi_callbacks, 
+		result = saEvtInitialize (&handle, &multi_callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -2240,7 +2241,7 @@ test_multi_channel3()
 	}
 
 	do {
-		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle, exp_data,  DATA_SIZE,
 								&event_id1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -2249,7 +2250,7 @@ test_multi_channel3()
 		goto evt_close;
 	}
 	do {
-		result = saEvtEventPublish(event_handle1, exp_data,  DATA_SIZE, 
+		result = saEvtEventPublish(event_handle1, exp_data,  DATA_SIZE,
 								&event_id2);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -2324,7 +2325,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result(0): %s\n", result_buf);
@@ -2332,7 +2333,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result(1): %s\n", result_buf);
@@ -2352,10 +2353,10 @@ evt_fin:
 
 /*
  * Test event retention
- *  	Test 1: publish the event with a retention time and then 
+ *  	Test 1: publish the event with a retention time and then
  *  			subscribe.  If the event was retained, we should receive it.
  *
- * 		Test 2: Publish the event, sleep until it expires, then 
+ * 		Test 2: Publish the event, sleep until it expires, then
  * 				subscribe.  We shouldn't get an event delivered.
  *
  * 		Test 3: Publish an event with a retention time.
@@ -2367,10 +2368,10 @@ evt_fin:
  *
  */
 #define EXPIRE_TIME 10 /* Seconds */
-SaEvtEventIdT retained_id;
-int got_event;
+static SaEvtEventIdT retained_id;
+static int got_event;
 
-void 
+static void
 event_callback_retained(SaEvtSubscriptionIdT my_subscription_id,
 		const SaEvtEventHandleT event_handle,
 		const SaSizeT my_event_data_size)
@@ -2395,8 +2396,8 @@ event_callback_retained(SaEvtSubscriptionIdT my_subscription_id,
 	got_event = 1;
 }
 
-void
-test_retention()
+static void
+test_retention(void)
 {
 	SaEvtHandleT handle;
 	SaEvtChannelHandleT channel_handle;
@@ -2413,7 +2414,7 @@ test_retention()
 	SaSelectionObjectT fd;
 	int timeout = (EXPIRE_TIME + 5);
 	SaAisErrorT result;
-	 
+
 	flags = SA_EVT_CHANNEL_PUBLISHER |
 		SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
@@ -2423,7 +2424,7 @@ test_retention()
 	printf("Test Event retention:\n");
 
 	do {
-		result = saEvtInitialize (&handle, &callbacks_retain, 
+		result = saEvtInitialize (&handle, &callbacks_retain,
 			versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 	if (result != SA_AIS_OK) {
@@ -2480,7 +2481,7 @@ test_retention()
 	}
 
 	/*
-	 * Test 1: publish the event with a retention time and then 
+	 * Test 1: publish the event with a retention time and then
 	 * subscribe.  If the event was retained, we should receive it.
 	 */
 	printf("       Receive retained event\n");
@@ -2551,7 +2552,7 @@ test_retention()
 	}
 
 	/*
-	 * Test 2:  Publish the event, sleep until it expires, then 
+	 * Test 2:  Publish the event, sleep until it expires, then
 	 * subscribe.  We shouldn't get an event delivered.
 	 */
 	printf("       Expire retained event\n");
@@ -2577,7 +2578,7 @@ test_retention()
 	}
 
 	/*
-	 * Wait for the event to expire, then subscribe.  We shouldn't get 
+	 * Wait for the event to expire, then subscribe.  We shouldn't get
 	 * an event
 	 */
 	sleep(timeout);
@@ -2738,7 +2739,7 @@ evt_close:
 	do {
 		result = saEvtChannelClose(channel_handle);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close result: %s\n", result_buf);
@@ -2756,7 +2757,7 @@ evt_fin:
 
 }
 
-void 
+static void
 unlink_chan_callback(SaEvtSubscriptionIdT my_subscription_id,
 		const SaEvtEventHandleT event_handle,
 		const SaSizeT my_event_data_size)
@@ -2799,7 +2800,7 @@ unlink_chan_callback(SaEvtSubscriptionIdT my_subscription_id,
 	}
 
 	if (my_subscription_id != exp_sub_id) {
-		printf("ERROR: sub ID: e=%x, a=%x\n", 
+		printf("ERROR: sub ID: e=%x, a=%x\n",
 				exp_sub_id, my_subscription_id);
 		goto evt_free;
 	}
@@ -2828,8 +2829,8 @@ SaEvtCallbacksT unlink_callbacks = {
 	open_callback,
 	unlink_chan_callback
 };
-void
-test_unlink_channel()
+static void
+test_unlink_channel(void)
 {
 	SaEvtHandleT handle;
 	SaEvtChannelHandleT channel_handle1;
@@ -2844,7 +2845,7 @@ test_unlink_channel()
 	int nfd;
 	SaSelectionObjectT fd;
 	int timeout = 5000;
-	 
+
 	flags1 = SA_EVT_CHANNEL_PUBLISHER |
 		SA_EVT_CHANNEL_SUBSCRIBER |
 		SA_EVT_CHANNEL_CREATE;
@@ -2856,7 +2857,7 @@ test_unlink_channel()
 	printf("Test Channel Unlink operations:\n");
 
 	do {
-		result = saEvtInitialize (&handle, &unlink_callbacks, 
+		result = saEvtInitialize (&handle, &unlink_callbacks,
 				versions[0].version);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
 
@@ -2920,7 +2921,7 @@ test_unlink_channel()
 	do {
 		result = saEvtChannelClose(channel_handle1);
 	} while ((result == SA_AIS_ERR_TRY_AGAIN) && !sleep(TRY_WAIT));
-	
+
 	if (result != SA_AIS_OK) {
 		get_sa_error(result, result_buf, result_buf_len);
 		printf("ERROR: channel close(1) result: %s\n", result_buf);
@@ -2943,7 +2944,7 @@ test_unlink_channel()
 	 * Unlink the channel.  Should mark for deletion but not
 	 *		delete it since it is already open.
 	 * Open the channel without create. This should fail since
-	 *		the channel is marked for deletion and a new version 
+	 *		the channel is marked for deletion and a new version
 	 *		hasn't been created.
 	 * Close channel.
 	 */
@@ -3027,7 +3028,7 @@ test_unlink_channel()
 	}
 
 	/*
-	 * 5. Open/create a channel, unlink channel, open/create channel, send 
+	 * 5. Open/create a channel, unlink channel, open/create channel, send
 	 * 		event on each.
 	 *
 	 * Open/create.
@@ -3190,14 +3191,14 @@ test_unlink_channel()
 		printf("ERROR: processed %d events\n", call_count);
 		goto unlink_exit;
 	}
-		
+
 
 	/*
 	 * 6. unlink all, close all.
 	 *
 	 * close all open channels.
 	 * unlink the channel.
-	 * open without create the channel.  Verify that the channel no 
+	 * open without create the channel.  Verify that the channel no
 	 * 		longer exists.
 	 */
 	printf("       6 Channel unlink all/close all/open:\n");
@@ -3217,6 +3218,7 @@ unlink_exit:
 	printf("Done\n");
 
 }
+
 int main (void)
 {
 	test_initialize ();
