@@ -6,7 +6,7 @@
  * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -32,6 +32,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -50,7 +51,7 @@
 SaNameT resource_name_async;
 SaLckResourceHandleT resource_handle_async;
 
-void testLckResourceOpenCallback (
+static void testLckResourceOpenCallback (
 	SaInvocationT invocation,
 	SaLckResourceHandleT lockResourceHandle,
 	SaAisErrorT error)
@@ -60,7 +61,7 @@ void testLckResourceOpenCallback (
 	resource_handle_async = lockResourceHandle;
 }
 
-void testLckLockGrantCallback (
+static void testLckLockGrantCallback (
 	SaInvocationT invocation,
 	SaLckLockStatusT lockStatus,
 	SaAisErrorT error)
@@ -69,10 +70,10 @@ void testLckLockGrantCallback (
 		(unsigned long long)invocation, lockStatus, error);
 }
 
-SaLckLockIdT pr_lock_id;
-SaLckLockIdT pr_lock_async_id;
+static SaLckLockIdT pr_lock_id;
+static SaLckLockIdT pr_lock_async_id;
 
-void testLckLockWaiterCallback (
+static void testLckLockWaiterCallback (
         SaLckWaiterSignalT waiterSignal,
         SaLckLockIdT lockId,
         SaLckLockModeT modeHeld,
@@ -90,7 +91,7 @@ void testLckLockWaiterCallback (
 	printf ("saLckResourceUnlockAsync result %d (should be 1)\n", result);
 }
 
-void testLckResourceUnlockCallback (
+static void testLckResourceUnlockCallback (
         SaInvocationT invocation,
         SaAisErrorT error)
 {
@@ -98,16 +99,16 @@ void testLckResourceUnlockCallback (
 		(unsigned long long)invocation, error);
 }
 
-SaLckCallbacksT callbacks = {
+static SaLckCallbacksT callbacks = {
 	.saLckResourceOpenCallback	= testLckResourceOpenCallback,
 	.saLckLockGrantCallback		= testLckLockGrantCallback,
 	.saLckLockWaiterCallback	= testLckLockWaiterCallback,
 	.saLckResourceUnlockCallback	= testLckResourceUnlockCallback
 };
 
-SaVersionT version = { 'B', 1, 1 };
+static SaVersionT version = { 'B', 1, 1 };
 
-void setSaNameT (SaNameT *name, char *str) {
+static void setSaNameT (SaNameT *name, const char *str) {
 	strncpy ((char *)name->value, str, SA_MAX_NAME_LENGTH);
 	if (strlen ((char *)name->value) > SA_MAX_NAME_LENGTH) {
 		name->length = SA_MAX_NAME_LENGTH;
@@ -116,15 +117,11 @@ void setSaNameT (SaNameT *name, char *str) {
 	}
 }
 
-void sigintr_handler (int signum) {
-	exit (0);
-}
-
 struct th_data {
 	SaLckHandleT handle;
 };
 
-void *th_dispatch (void *arg)
+static void *th_dispatch (void *arg)
 {
 	struct th_data *th_data = (struct th_data *)arg;
 
@@ -132,6 +129,10 @@ void *th_dispatch (void *arg)
 	return (0);
 }
 
+static void sigintr_handler (int signum) {
+	exit (0);
+}
+
 int main (void) {
 	SaLckHandleT handle;
 	SaLckResourceHandleT resource_handle;
@@ -185,7 +186,7 @@ int main (void) {
 		&resource_name_async,
 		SA_LCK_RESOURCE_CREATE);
 	printf ("saLckResourceOpenAsync %d (should be 1)\n", result);
-		
+
 	result = saLckResourceLock (
 		resource_handle,
 		&pr_lock_id,
@@ -223,7 +224,7 @@ int main (void) {
 		&status);
 	printf ("saLckResourceLock EX %d (should be 1)\n", result);
 	printf ("status %d\n", status);
-		
+
 	result = saLckResourceLockAsync (
 		resource_handle_async,
 		0x56,
@@ -242,14 +243,14 @@ int main (void) {
 			break;
 		}
 	} while (result);
-	
+
 	printf ("Starting saLckResourceUnlock\n");
 	result = saLckResourceUnlock (
 		ex_lock_id,
 		SA_TIME_END);
 	printf ("saLckResourceUnlock result %d (should be 1)\n",
 		result);
-	
+
 	result = saLckResourceClose (resource_handle);
 	printf ("saLckResourceClose result %d (should be 1)\n", result);
 
